@@ -11,16 +11,6 @@ impl Blockchain<'_> {
     /// If not saved, will grab from peer in
     /// peer list
     ///
-    /// #Examples
-    /// ```
-    /// use super::chain::get_tip;
-    ///
-    /// fn main() {
-    ///     let bc = Blockchain::default();
-    ///     bc.get_tip();
-    /// }
-    /// ```
-    ///
     pub fn get_tip(&self) {
         // Check network for current block
     }
@@ -30,15 +20,6 @@ impl Blockchain<'_> {
 /// Read blockchain from file and load
 /// into hashmap
 ///
-/// #Examples
-/// ```
-/// use super::chain::init_blockchain;
-///
-/// fn main() {
-///     let blockchain = init_blockchain("test_blockchaindb").unwrap();
-/// }
-/// ```
-///
 pub fn init_blockchain(db_name: &'static str) -> Result<Blockchain, lmdb::Error> {
     // Get handle to blockchain db
     let db: lmdb::Database = get_lmdb_connection(db_name)?;
@@ -56,10 +37,10 @@ pub fn init_blockchain(db_name: &'static str) -> Result<Blockchain, lmdb::Error>
     let access = tx.access();
 
     // Get last block saved in database
-    let last_block: &Block = curs.last::<str, Block>(&access)?.1;
-    {
-        blockchain.tip = *last_block;
-    }
+//   let last_block: &Block = curs.last::<str, Block>(&access)?.1;
+//   {
+//       blockchain.tip = *last_block;
+//   }
 
     Ok(blockchain)
 }
@@ -68,14 +49,6 @@ pub fn init_blockchain(db_name: &'static str) -> Result<Blockchain, lmdb::Error>
 /// Creates a file for storing the blockchain
 /// database
 ///
-/// # Examples:
-/// ```
-/// use super::chain::get_lmdb_connection;
-///
-/// fn main() {
-///     let test_db = get_lmdb_connection("test_blockchaindb");
-/// }
-/// ```
 pub fn get_lmdb_connection(env: &'static str) -> Result<lmdb::Database, lmdb::Error> {
     // Create directory for lmdb
     std::fs::create_dir_all(env).unwrap();
