@@ -38,8 +38,9 @@ mod tests {
     }
 
     #[test]
-    fn test_blockchain() {
+    fn test_blockchain() -> std::io::Result<()>{
         let _bc: Blockchain = init_blockchain("test_blockchaindb").unwrap();
+        Ok(())
     }
 
     #[test]
