@@ -9,7 +9,7 @@ pub use crate::daemon::daemon::daemon_startup;
 #[cfg(test)]
 
 mod tests {
-    use crate::daemon::daemon_startup;
+    use super::daemon::*;
     #[test]
     fn test_daemon() -> std::io::Result<()> {
         let _dpid = daemon_startup("test_blockchaindb");
